@@ -547,6 +547,42 @@ class UserStoryStatuses(MoveOnDestroyMixinList, ListResource):
         return self._new_resource(payload=attrs)
 
 
+class SwimLane(MoveOnDestroyMixinObject, InstanceResource):
+    """
+    Taiga Swimlane model
+
+    :param name: The name of :class:`SwimLane`
+    :param order: the order of :class:`SwimLane`
+    :param project: the project of :class:`SwimLane`
+    :param statuses: the statuses of :class:`SwimLane`
+    """
+
+    repr_attribute = "name"
+
+    endpoint = "swimlanes"
+
+    allowed_params = ["name", "order", "project", "statuses"]
+
+    parser = {
+        "statuses": UserStoryStatuses,
+    }
+
+
+class SwimLanes(MoveOnDestroyMixinList, ListResource):
+    instance = SwimLane
+
+    def create(self, project, name, **attrs):
+        """
+        Create a new :class:`SwimLane`.
+
+        :param project: :class:`Project` id
+        :param name: name of :class:`SwimLane`
+        :param attrs: optional attributes of :class:`SwimLane`
+        """
+        attrs.update({"project": project, "name": name})
+        return self._new_resource(payload=attrs)
+
+
 class Point(MoveOnDestroyMixinObject, InstanceResource):
     """
     Taiga Point model
@@ -1156,6 +1192,7 @@ class Project(InstanceResource):
     allowed_params = [
         "name",
         "description",
+        "default_swimlane",
         "creation_template",
         "is_backlog_activated",
         "is_issues_activated",
@@ -1179,6 +1216,7 @@ class Project(InstanceResource):
         "points": Points,
         "us_statuses": UserStoryStatuses,
         "milestones": Milestones,
+        "swimlanes": SwimLanes,
     }
 
     def get_item_by_ref(self, ref):
@@ -1347,6 +1385,21 @@ class Project(InstanceResource):
         """
         return UserStories(self.requester).list(project=self.id, **queryparams)
 
+    def add_swimlane(self, name, **attrs):
+        """
+        Adds a :class:`SwimLane` and returns a :class:`SwimLane` resource.
+
+        :param name: name of :class:`SwimLane`
+        :param attrs: other :class:`SwimLane` attributes
+        """
+        return SwimLanes(self.requester).create(self.id, name, **attrs)
+
+    def list_swimlanes(self, **queryparams):
+        """
+        Returns the :class:`SwimLane` list of the project.
+        """
+        return SwimLanes(self.requester).list(project=self.id, **queryparams)
+
     def add_issue(self, subject, priority, status, issue_type, severity, **attrs):
         """
         Adds a Issue and returns a :class:`Issue` resource.
@@ -1701,6 +1754,20 @@ class Project(InstanceResource):
         response = self.requester.get("/{}/{}/tags_colors".format(self.endpoint, self.id))
         return response.json()
 
+    def duplicate(self, name, description, is_private=False, users=[], **attrs):
+        """
+        Duplicate a :class:`Project`
+
+        :param name: name of new :class:`Project`
+        :param description: description of new :class:`Project`
+        :param is_private: determines if the project is private or not
+        :param users: users of the new :class:`Project`
+        :param attrs: optional attributes for the new :class:`Project`
+        """
+        attrs.update({"name": name, "description": description, "is_private": is_private, "users": users})
+        response = self.requester.post("/{endpoint}/{id}/duplicate", payload=attrs, endpoint=self.endpoint, id=self.id)
+        return self.parse(self.requester, response.json())
+
 
 class Projects(ListResource):
     """
@@ -1765,7 +1832,7 @@ class WikiPage(InstanceResource):
 
     repr_attribute = "slug"
 
-    allowed_params = ["project", "slug", "content", "watchers"]
+    allowed_params = ["project", "slug", "content", "watchers", "version"]
 
     def attach(self, attached_file, **attrs):
         """
